@@ -29,7 +29,7 @@
 #include <QDialog>
 #include <QPixmap>
 #include <QTreeWidget>
-#include <QtCore/QHash>
+#include <QHash>
 
 #include <kcombobox.h>
 #include <kfileitem.h>
@@ -189,7 +189,7 @@ public:
                      const QString &qualifier = QString());
     virtual ~KACLListViewItem();
     QString key() const;
-    bool operator< (const QTreeWidgetItem &other) const Q_DECL_OVERRIDE;
+    bool operator< (const QTreeWidgetItem &other) const override;
 
     void calcEffectiveRights();
 
